# Django PFX

![pipeline]
![coverage]

![logo]

Django PFX is a toolkit to build web APIs dedicated to be used by React progressive web app.

> **WARNING**
>
> This is an experimental projet. It should not be used in real project because it is incomplete and there is no warranty of keeping compatibility in future version.

[logo]: https://gitlab.com/hmartinet/django-pfx/-/raw/master/img/pfx.png "PFX"
[pipeline]: https://gitlab.com/hmartinet/django-pfx/badges/master/pipeline.svg "Pipeline Status"
[coverage]: https://gitlab.com/hmartinet/django-pfx/badges/master/coverage.svg "Code Coverage"
